Coverage for src/django_resume/plugins/about.py: 100%

1 from django import forms

2

3 from .base import SimplePlugin, SimpleTemplates

4

5

6 class AboutForm(forms.Form):

7 text = forms.CharField(

8 label="About",

9 max_length=1024,

10 initial="Some about text...",

11 widget=forms.Textarea,

12 )

13

14

15 class AboutPlugin(SimplePlugin):

16 name: str = "about"

17 verbose_name: str = "About"

18 templates = SimpleTemplates(

19 main="django_resume/about/plain/content.html",

20 form="django_resume/about/plain/form.html",

21 )

22 admin_form_class = inline_form_class = AboutForm